@@ -299,18 +299,28 @@ int ssl_connect(int sock, SSL ** ssl_con)
 {
    SSL_METHOD *meth;
    SSL_CTX *ctx;
-
+   X509 *cert = NULL;
+   int i;
+   
    SSL_library_init();
    SSL_load_error_strings();
-
+   
    meth = (SSL_METHOD *) TLSv1_method();
    ctx = SSL_CTX_new(meth);
-
+   
    *ssl_con = SSL_new(ctx);
    SSL_set_fd(*ssl_con, sock);
    if (SSL_connect(*ssl_con) <= 0)
       return -1;
-
+   
+   cert = SSL_get_peer_certificate(*ssl_con);
+   if (cert == NULL)
+      return -1;
+   
+   i = SSL_get_verify_result(*ssl_con);
+   if (i != X509_V_OK)
+      printf("Possibly invalid certificate, continue on your own risk!\n");
+   
    return 0;
 }
 #endif
@@ -962,8 +972,6 @@ INT submit_elog(char *host, int port, int ssl, char *subdir, char *experiment,
       printf("Error: No logbook specified\n");
    else if (strstr(response, "enter password"))
       printf("Error: Missing or invalid password\n");
-   else if (strstr(response, "form name=form1"))
-      printf("Error: Missing or invalid user name/password\n");
    else if (strstr(response, "Error: Attribute")) {
       if (strstr(response, "not existing")) {
          strncpy(str, strstr(response, "Error: Attribute") + 27, sizeof(str));
@@ -976,7 +984,10 @@ INT submit_elog(char *host, int port, int ssl, char *subdir, char *experiment,
             *strchr(str, '<') = 0;
          printf("Error: Missing required attribute \"%s\"\n", str);
       }
-   } else
+   }
+   else if (strstr(response, "form name=form1"))
+      printf("Error: Missing or invalid user name/password\n");
+   else
       printf("Error transmitting message\n");
 
    return 1;
